@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: power-management.c,v 1.9 2005/07/14 12:47:34 ryanl Exp $
+ $Id: power-management.c,v 1.10 2005/08/26 03:45:47 ryanl Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -426,12 +426,16 @@ power_management_getinfo( BatteryStatus *status )
  * the problem might be.  This error message is not to be freed.
  */
 const char *
-power_management_initialise( void )
+power_management_initialise( int no_hal )
 {
 #ifdef HAVE_HAL
   char *err;
 
-  err = battstat_hal_initialise();
+  if( no_hal )
+    err = g_strdup( ":(" );
+  else
+    err = battstat_hal_initialise();
+
 
   if( err == NULL ) /* HAL is up */
   {
@@ -515,3 +519,9 @@ power_management_cleanup( void )
 
   pm_initialised = 0;
 }
+
+int
+power_management_using_hal( void )
+{
+  return using_hal;
+}
